@@ -25,8 +25,10 @@ class CNN(tf.keras.Model):
         self.dense_1 = layers.Dense(units=ffn_units, activation='relu')
         self.dropout = layers.Dropout(rate=dropout_rate)
 
-        self.last_dense = layers.Dense(
-            units=nb_classes, activation='softmax')
+        if nb_classes == 2:
+            self.last_dense = layers.Dense(units = 1, activation = 'sigmoid')
+        else:
+            self.last_dense = layers.Dense(units = nb_classes, activation = 'softmax')
 
     def call(self, inputs, training):
         x = self.embedding(inputs)
