@@ -11,18 +11,20 @@ import os
 from pathlib import Path
 import tarfile
 import gdown
+from symspellpy import SymSpell, Verbosity
 
 def get_dataframe_from_mongo(mongo_conn, collection):
     products_df = mongo_conn.db[collection].find({}).sort('created', pymongo.DESCENDING)
     
     return pd.DataFrame(products_df[0]['df']) if products_df else ''
 
-def get_cleaned_predictor(description, product_name):
+def get_cleaned_predictor(sym_spell, description, product_name):
     description = list(map(get_description_and_name, description))
     product_name = list(map(get_description_and_name, product_name))
 
     X = join_all_predictors(description, product_name)
 
+    X = correct_word_spelling(sym_spell, X)
     return X
 
 def get_description_and_name(data):    
@@ -98,3 +100,27 @@ def download_model(url, output):
     tar.extractall('/'.join(output.split('/')[0:-1]))
     tar.close()
     os.remove(output)
+
+def instantiate_spelling_corrector():
+    sym_spell = SymSpell(max_dictionary_edit_distance=2, prefix_length=7)
+
+    sym_spell.load_dictionary('./src/utils/datasets/dictionary.txt', term_index=0, count_index=1)
+    sym_spell.load_bigram_dictionary('./src/utils/datasets/word_bigram.txt', 0, 2)
+
+    return sym_spell
+
+def correct_word_spelling(sym_spell, corpus):
+    final_corpus = []
+    print('Correcting word spelling')
+    for phrase in corpus:
+        new_phrase = []
+        for input_term in phrase.split():
+            suggestion = sym_spell.lookup(input_term, Verbosity.TOP, 
+                                    max_edit_distance=2)
+        
+            if len(suggestion) > 0:
+                new_phrase.append(suggestion[0].term)               
+
+        final_corpus.append(' '.join(new_phrase))
+
+    return final_corpus
